.. _dg-imperative_burgers_1D:

dg/imperative_burgers_1D.py
===========================

**Description**


Burgers equation in 1D solved using discontinous Galerkin method




:download:`source code </../sfepy/examples/dg/imperative_burgers_1D.py>`

.. literalinclude:: /../sfepy/examples/dg/imperative_burgers_1D.py

